/******************************************************************************/
/*
 * eRIC Example ADC V1.0
 * Low Power Radio Solutions
 * December 2016
 * Built with CCS V6.1.2.00015
 * This example will demonstrate how ADC works. Two example are provided which can be included by #defines.
 * #define ADC_OnLeds: Pin1(Analog pin) is connected to Potentiometre.By turning the knob on potentiomtre and
 * using ADC, LED1-4 can be lit.
 * #define Transmit_ADC: ADC value on Pin 1 is transmitted over air and also it is sent ot uart at 19200 baud. It will only transit/send
 * if there is a difference of 100 in adc value.
 *
 *
 */

/******************************************************************************/
//Version V1.0
#include<cc430f5137.h>
#include "eRIC.h"
#define ADC_OnLeds
#define Transmit_ADC

int main(void)
{
	eRIC_WDT_Stop();                   //Stop watch dog timer, just in case
	eRIC_GlobalInterruptDisable();     //Global interrupts disabled

	eRIC_SetCpuFrequency(5000000);    //Sets CPU clock to 5mHz
	eRIC_SetAdcPin(1);                //Set Pin1 as ADC
	eRIC_SetAdcRefVoltage(eRICADCRef_2_0v,0);  //Put 2.5v on pin22. THis is not really neccessary if you put some voltage on PIn1
	Pin16_SetAsOutput(); //Set pin16 output
	Pin17_SetAsOutput(); //Set pin17 output
	Pin18_SetAsOutput(); //Set pin18 output
	Pin19_SetAsOutput(); //Set pin19 output
	 eRIC_UARTAInitialise(19200);   //Initialise Uart with 19200 baud to send captured value
	 Pin3_FunctionUartATxOUT();
	eROS_Initialise(434000000);
	eRIC_GlobalInterruptEnable();
	volatile int ADCvalue;
	volatile int TempADCvalue = 0;
	volatile unsigned int diff = 0;
	while(1)
	{
	    ADCvalue =  ReadAdc(); //Read adc value on PIn1, it will be 0-4095 as it is 12 bit adc. 0v will give 0 and 2.5 v will give 4095 value

	    #ifdef ADC_OnLeds
	     if(ADCvalue >500) //IF adc is higher than 500 or  .305v
	    {
	        Pin19_SetHigh(); //Set pin19 high
	        if(ADCvalue >1024) //IF adc is higher than 1024 or  .625v
	        {
	            Pin18_SetHigh(); //Set pin18 high
	            if(ADCvalue >2048) //IF adc is higher than 2048 or  1.25v
	            {
	                Pin17_SetHigh(); //Set pin17 high
	                if(ADCvalue >3072) //IF adc is higher than 3072 or  1.875v
	                {
	                    Pin16_SetHigh(); //Set pin16 high
	                }
	                else
	                   Pin16_SetLow();
	            }
	            else
	                Pin17_SetLow();
	        }
	        else
	            Pin18_SetLow();
	    }
	    else
	        Pin19_SetLow();
        #endif
        #ifdef Transmit_ADC
	    diff = TempADCvalue-ADCvalue;
	    if(diff>100)
	    {
	        TempADCvalue = ADCvalue;
	        eRIC_UartASendByte(ADCvalue>>8);        //send high byte to Uart
	        while(eRIC_UartATxBufferIsBusy());
	        eRIC_UartASendByte(ADCvalue);        //send low byte to Uart
	        while(eRIC_UartATxBufferIsBusy());
	        eRIC_RadioTx_BuffCount = 0;
	        eRIC_RadioTx_Buffer[eRIC_RadioTx_BuffCount++] = ADCvalue>>8; //send high byte over air
	        eRIC_RadioTx_Buffer[eRIC_RadioTx_BuffCount++] = ADCvalue; //send low byte over air
	        eRIC_RfSenddata();//send data
	    }
        #endif
	}//end of while(1)
}//end of main()


void eRIC_RfDataReceivedInterrupt()   // Add code here to deal with  available received data..THis is triggered when interrupt is enabled and a apcket is received
{
}
